from dotenv import load_dotenv
from requests import get,post,put
from discord import SyncWebhook
from datetime import datetime as dt, timezone as tz
from time import mktime
from feedparser import parse
from os import getenv
from json import loads
from time import mktime

# initialise variables
new_ts = dt.now(tz.utc)
old_ts = ''

# read in old timestamp if it exists
try:
  old_ts = dt.strptime(open('last_check','r').read().split(".")[0],'%Y-%m-%d %H:%M:%S')
except:
  old_ts = dt.strptime('20230101000000','%Y-%m-%d %H:%M:%S')

# load in the relevant .env variables
load_dotenv()
discord_user = getenv('DISCORD_USERNAME')
discord_webhook_url = getenv('DISCORD_WEBHOOK')
webhook = SyncWebhook.from_url(getenv('DISCORD_WEBHOOK'))
github_token = getenv('GITHUB_TOKEN')

# list of repos to check
repos = [
    'neovim/neovim',
    'mastodon/mastodon',
    'hometown-fork/hometown',
    'glitch-soc/mastodon',
    'superseriousbusiness/gotosocial'
  ]

github_api = 'https://api.github.com/repos'

headers = {
    'Accept': 'application/vnd.github+json',
    'Authorization': f'Bearer {github_token}',
    'X-GitHub-Api-Version': '2022-11-28'
  }

# loop through urls for latest release

def get_latest_releases():
  for repo in repos:
    release_url = f'{github_api}/{repo}/releases/latest'
    # print(release_url)
    latest_release = get(release_url, headers=headers)
    if latest_release.status_code == 200:
      release_details = loads(latest_release.text)
      if mktime(dt.strptime(release_details['published_at'], '%Y-%m-%dT%H:%M:%SZ').timetuple()) > mktime(old_ts.timetuple()):
        print(
            release_details['tag_name'],
            release_details['name'],
            release_details['published_at'],
            release_details['html_url']
          )
        webhook.send(f"{release_details['name']}: {release_details['tag_name']}\n{release_details['html_url']}")
      else:
        print(latest_release.status_code, latest_release.reason)
    else:
      return False

## return true if the function didn't terminate abnormally before
    return True

if __name__ == "__main__":
  results_sent = get_latest_releases()
  if results_sent:
    with open('last_check','w') as f:
      print(new_ts, file=f, end='')
